package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````41<``#0```",@0````0`!30`(``)
M`"@`&P`:``$``'#8>0``V'D``-AY```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#D>0``Y'D```4```````$`
M`0```)Q]``"<?0$`G'T!`*0"``"\$@``!@```````0`"````I'T``*1]`0"D
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DG'T`
M`)Q]`0"<?0$`9`(``&0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50#^_^<29D+GP3\)]6:2?![?JRS#.!$```!0````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(PXH!)%B@``"%````!1````5```
M`%@```!9````8````&$```!B````9````&4`````````9P```&@```!I````
M:P```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M````````````:!(````````#``L```````"``0```````P`6`)`"````````
M`````!(````^`P`````````````2````$@,`````````````(@```%<#````
M`````````!$```#:`P`````````````2````$0``````````````(````.\!
M`````````````!(```#D`@`````````````2````+P,`````````````$@``
M`!$!`````````````!(```"'`P`````````````1````M```````````````
M$@```*L"`````````````!(```"#`0`````````````2````EP(`````````
M````$@```(0``````````````!(````,`0`````````````2````L@(`````
M````````$@```'0"`````````````!(````Z`@`````````````2````80,`
M````````````$@```$L"`````````````!(```!8`@`````````````2````
M`0$`````````````$0```&<!`````````````!(```#C```````````````1
M````-0$`````````````$@```.L"`````````````!(```#=`@``````````
M```1````]`(`````````````$@```,(``````````````!(```"Q`0``````
M```````2````"P(`````````````$@```)X!`````````````!(```#+`@``
M```````````2````$P(`````````````$@```*H!`````````````!(```!%
M`P`````````````2````0P$`````````````$@```"T``````````````"``
M``!M`@`````````````2````)`(`````````````$@```(("````````````
M`!(```"\`0`````````````1````9```````````````$@````$#````````
M`````!(```"3```````````````2````]`$`````````````$@```"$#````
M`````````!(```"?```````````````2````7`$`````````````$@```%("
M`````````````!(```")`@`````````````2````(@$`````````````$@``
M`%8``````````````!(````6`0`````````````2````DP$`````````````
M$@```)T"`````````````!(```#P```````````````2````9@(`````````
M````$@```#<#`````````````!(```![`@`````````````2````=0$`````
M````````$@```',``````````````!(```!8`P`````````````A````"`,`
M````````````$@```-0``````````````!(```!3`0`````````````2````
M/```````````````(````%D#`````````````!$```#3`@`````````````2
M````*0(`````````````$@```&`"`````````````!(````%`@``````````
M```2````P`(`````````````$@```#$"`````````````!(```#;`0``````
M```````2````]P,``%B0`0``````$``7`.,#``"%.0``4````!(`#0`;!```
MD2\``#0'```2``T`4@,``)D5``"X`0``$@`-`*D#``"!*@``!````!(`#0"Z
M`P``0(`!```````0`!<`H@0``(4J``"@`0``$@`-`,\$``#%-@``P`(``!(`
M#0".!```0(`!```````0`!<``@0``"4L```6````$@`-`#4$```P.@``!```
M`!$`#P!T!```6)`!```````0`!<`>00``%B0`0``````$``7`)H$``!I*0``
M.````!(`#0"O!```\2X``*`````2``T`P00``($N``!@````$@`-`"@$````
M@`$``````!``%@`/!```/2P``,`````2``T`[P,``$"``0``````$``6`&H$
M```\@`$`!````!$`%@"9`P``%3H```(````2``T`6@0``-4Y``!`````$@`-
M`"X$``!1%P```````!(`#0`J!````(`!```````@`!8`R`,``.$N```0````
M$@`-`/8#``!8D`$``````!``%P!$!```[2D``)0````2``T`@00``/TL``"$
M`0``$@`-``!L:6)P97)L+G-O+C4N,C@`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR
M7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO
M861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C
M`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P
M96-I9FEC`')E860`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L<V5E:S8T`&]P
M96XV-`!L:6)C+G-O+C8`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?<W1A8VM?
M8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E
M='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER
M`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V
M-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`%]?
M;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!L9"UL:6YU>"UA
M<FUH9BYS;RXS`%]?<W1A8VM?8VAK7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P
M87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T
M87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI
M8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E
M;G8`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`
M1TQ)0D-?,BXT```````````"``(``@`"``(````#``(``@`"``0````"````
M`@```````@`"``(``@`"``(````````````"``(``@```````P````(``P`"
M``(```````(``@`"```````"`````P`"```````"``(````````````"````
M`@`"``(```````(``@`````````"``(``@`"``,``@`"``,``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$`<P,``!`````@````%&EI#0``!`#E!`````````$``0#+`0``$```
M`"`````4:6D-```#`.4$`````````0`!`!H"```0`````````!1I:0T```(`
MY00```````"<?0$`%P```*!]`0`7````P'\!`!<```#H?P$`%P```/!_`0`7
M````!(`!`!<````,@`$`%P```!"``0`7````&(`!`!<````<@`$`%P```""`
M`0`7````)(`!`!<````H@`$`%P```#"``0`7````-(`!`!<````\@`$`%P``
M`,1_`0`5!0``R'\!`!4(``#,?P$`%0T``-!_`0`5$```U'\!`!4:``#8?P$`
M%1P``-Q_`0`5'P``X'\!`!4J``#D?P$`%2X``.Q_`0`5.```]'\!`!5"``#X
M?P$`%4<``/Q_`0`52```P'X!`!8#``#$?@$`%@0``,A^`0`6!0``S'X!`!8'
M``#0?@$`%@D``-1^`0`6"@``V'X!`!8+``#<?@$`%@P``.!^`0`6#@``Y'X!
M`!8/``#H?@$`%A$``.Q^`0`6$@``\'X!`!83``#T?@$`%A0``/A^`0`6%0``
M_'X!`!86````?P$`%A<```1_`0`6&```"'\!`!89```,?P$`%AL``!!_`0`6
M'0``%'\!`!8>```8?P$`%B```!Q_`0`6(0``('\!`!8B```D?P$`%B,``"A_
M`0`6)```+'\!`!8E```P?P$`%B8``#1_`0`6)P``.'\!`!8H```\?P$`%BD`
M`$!_`0`6*@``1'\!`!8K``!(?P$`%BP``$Q_`0`6+0``4'\!`!8O``!4?P$`
M%C```%A_`0`6,0``7'\!`!8R``!@?P$`%C,``&1_`0`6-```:'\!`!8U``!L
M?P$`%C8``'!_`0`6-P``='\!`!8Y``!X?P$`%CH``'Q_`0`6.P``@'\!`!8\
M``"$?P$`%CT``(A_`0`6/@``C'\!`!8_``"0?P$`%D```)1_`0`600``F'\!
M`!9$``"<?P$`%D4``*!_`0`61@``I'\!`!9)``"H?P$`%DH``*Q_`0`62P``
ML'\!`!9,``"T?P$`%DT``+A_`0`63@``O'\!`!9/```(0"WI20$`ZPB`O>@$
MX"WE!."?Y0[@C^`(\+[E,&P!``#&C^(6RHSB,/R\Y0#&C^(6RHSB*/R\Y0#&
MC^(6RHSB(/R\Y0#&C^(6RHSB&/R\Y0#&C^(6RHSB$/R\Y0#&C^(6RHSB"/R\
MY0#&C^(6RHSB`/R\Y0#&C^(6RHSB^/N\Y0#&C^(6RHSB\/N\Y0#&C^(6RHSB
MZ/N\Y0#&C^(6RHSBX/N\Y0#&C^(6RHSBV/N\Y0#&C^(6RHSBT/N\Y0#&C^(6
MRHSBR/N\Y7A'P$8`QH_B%LJ,XKS[O.4`QH_B%LJ,XK3[O.5X1\!&`,:/XA;*
MC.*H^[SE`,:/XA;*C.*@^[SE`,:/XA;*C.*8^[SE`,:/XA;*C.*0^[SE`,:/
MXA;*C.*(^[SE`,:/XA;*C.*`^[SE`,:/XA;*C.)X^[SE`,:/XA;*C.)P^[SE
M`,:/XA;*C.)H^[SE`,:/XA;*C.)@^[SE`,:/XA;*C.)8^[SE`,:/XA;*C.)0
M^[SE`,:/XA;*C.)(^[SE`,:/XA;*C.)`^[SE`,:/XA;*C.(X^[SE`,:/XA;*
MC.(P^[SE`,:/XA;*C.(H^[SE`,:/XA;*C.(@^[SE`,:/XA;*C.(8^[SE`,:/
MXA;*C.(0^[SE`,:/XA;*C.((^[SE`,:/XA;*C.(`^[SE`,:/XA;*C.+X^KSE
M`,:/XA;*C.+P^KSE`,:/XA;*C.+H^KSE`,:/XA;*C.+@^KSE>$?`1@#&C^(6
MRHSBU/J\Y0#&C^(6RHSBS/J\Y0#&C^(6RHSBQ/J\Y0#&C^(6RHSBO/J\Y0#&
MC^(6RHSBM/J\Y0#&C^(6RHSBK/J\Y0#&C^(6RHSBI/J\Y0#&C^(6RHSBG/J\
MY0#&C^(6RHSBE/J\Y0#&C^(6RHSBC/J\Y0#&C^(6RHSBA/J\Y0#&C^(6RHSB
M?/J\Y0#&C^(6RHSB=/J\Y0#&C^(6RHSB;/J\Y0#&C^(6RHSB9/J\Y0#&C^(6
MRHSB7/J\Y0#&C^(6RHSB5/J\Y0#&C^(6RHSB3/J\Y0#&C^(6RHSB1/J\Y0#&
MC^(6RHSB//J\Y0#&C^(6RHSB-/J\Y0#&C^(6RHSB+/J\Y0````#PM8FP64Q:
M2WQ$!9`$D06H`Y($J>98`ZHS:`>3__=$[U1*54NB6.!8$48"\"GZ4TOC6!]X
M`"]JT%%+Y5@H:/_WV.^0^,8S`D8H:$/P`@."^,8S__?.[P6;!3.S\8!/D/C&
M(T+P`0*`^,8C<]*8``0G__?>[D-*!)UZ1$-+$6A[1$)*+&AZ1$-@P.D"$D!+
M!9I[1`1@`2K#Z0%PPK\`\0P!*QT%ZX(%!=U3^`1+G4)!^`1/^=$W3P+Q@$$`
M)`,Q?T0`E$#X(4`#1CUI`S(R22A&>43_]R[O!$9(LS!-!J]]1"AI__=\[BY(
M.49X1`#P,O\0LRQ+>T08:?_W0N[_]PSO!YHS:"!&FD(MT0FP\+W_]X3N)4IZ
M1!!A$+/_]RSN&$OE6"AH__=D[X#X<7>&YSAI__<T[P1&T.?H:!"Q`O!6^=?G
M&D@Y1GA$`/`$_^A@`"C/T//G%DL72.%8>$3_]\+N`2#_]Y;N__<@[@"_$&D!
M`!@!```X`0``0`$``"0!```@`0``*&H!`%HG``!8)P``&&H!`.II`0`U$P``
MRFD!`*8D``"T:0$`E&D!`.8C```P`0``MB4``$_P``M/\``.`KQJ1@2T`;3?
M^"2@"*.:1-_X(,!:^`S`3?@$S09+6O@#,`9(6O@``/_W.N[_]^CN+&<!``P!
M```T`0``/`$``!0PG^44()_E`S"/X`(@D^<``%+C'O\O`1;__^H,9P$`+`$`
M``9(!TMX1`=*>T2#0GI$`]`%2]-8`[$81W!'`+]\:`$`>&@!`.AF`0`4`0``
M"$@)2WA$"4I[1!D:>D2)$`'KT7%)$`/0!4O36`.Q&$=P1P"_4&@!`$QH`0"\
M9@$`1`$```BU"DL*2GM$>D0;>&NY"4O36".Q"$M[1!AH__<T[?_WO_\&2P$B
M>T0:<`B]&F@!`(QF`0`0`0``SF<!`/IG`0#$YP"_W_B`/`#Q0`$MZ?!/>T3?
M^'A,K?4E?0*M`/&`!P`F&UDJ1KQ&`9,;:*.34>D"=`@QC$568-9@/[I/ZA0C
M3^H$+@/T?T,.]'\.0^H48Q=@0^H$8P+Q$`)#Z@X#0O@(/.31!?7\=6E&`":&
M1HQ&4?@(#]SX<"#<^$@PJ4+<^!APW/AT0(/J`@/<^$P@@^H'`]SX''"#Z@`#
M@NH$`DQH@NH'`D_JTW>"Z@0"P?B$8$?J0@='ZD,#P?B`,-?1<$;>Z0)CWND`
MQ`=I3^J6#H)I3NJ#?@*93^K<98?J`@E']ID3`FK%]H(C1>I$%<D81>I,%8D8
M:1B%:02:">H&"4[JAGZ)Z@4)3^J<!1'K"0&'Z@X(1>J$==08@FD(Z@P(1>J,
M=8CJ!PBD&`::CNH%"13K"`1/ZO%H%.L(!`GJ`0D2ZP,(3^JQ`8GJ#@(8ZP<(
MW?@@D$_J]&H8ZP("A>H!"!+K"@((Z@0(&>L#"4_JM`2(Z@4(&>L.#MWX*)!/
MZO)J'NL(#H'J!`@>ZPH.".H""!GK`PE/ZK("B.H!"!GK!07=^#"03^K^:A7K
M"`6$Z@((%>L*!0CJ#@@9ZP,)3^J^#HCJ!`@9ZP$!W?@XH!'K"`&"Z@X)3^KU
M:!'K"`@)Z@4)&NL#"D_JM0&)Z@()&NL$!-WX0*".Z@$%%.L)!$_J^&D4ZPD$
M!>H(!1KK`PI/ZK@(A>H.!1KK`@+=^$B@4AF!Z@@)3^KT9549">H$"1KK`PH*
M1AKK#@Y/ZK0!W?A0H(GJ`@0>ZP0$3^KU:8CJ`0X4ZPD$#NH%#AKK`PE/ZK4%
M&>L""8[J"`Y"1MWX6(!/ZO1J&>L.#H'J!0D>ZPH.">H$"1CK`PC=^&"@&.L"
M"$_JM`*)Z@$$3^K^:1CK!`2%Z@((%.L)!`CJ#@@:ZP,)3^J^#AGK`0F(Z@4(
M*48:G4_J]&H9ZP@(@NH."1CK"@@)Z@0)[1AM&-WX<*!/ZK0!B>H"!"P93^KX
M:8[J`044ZPD$!>H(!1KK`PE/ZK@(&>L""7)&W?AXX%5`3^KT:AGK!06!Z@@)
M%>L*!0GJ!`D>ZP,.W?B`H![K`@Y/ZK0"B>H!!$_J]6D>ZP0$B.H"#A3K"00.
MZ@4.&NL#"4_JM06.Z@@.&>L!"4%&W?B(@$_J]&H9ZPX)@NH%#AGK"@D.Z@0.
M&.L#"$_JM`2.Z@(.&.L!`=WXD(!/ZOEJ$>L.`87J!`X1ZPH!#NH)#ACK`PA/
MZKD)CNH%#ACK`@+=^)B`3^KQ:A+K#@*$Z@D.$NL*`@[J`0X8ZP,(3^JQ`1CK
M!06.Z@0(W?B@X$_J\FH5ZP@(B>H!!1CK"@@50![K`PZ%Z@D%'NL$#BJ;3^JR
M`A[K!0Y.]J$T3^KX9<;VV60>ZP4.@>H"!1L9A>H(!1/K"0DLFT_JN`@9ZP4)
M3^K^91GK!0F"Z@@%&QF%Z@X%6Q@NF4_JO@Y;&4_J^65;&8CJ#@4)&87J"06)
M&#":3^JY"4T93^KS86T8CNH)`1(964`2ZP@(,II/ZK,#&.L!`4_J]6B)Z@,*
M$>L(`1(9BNH%"MWXT(`2ZPX"3^JU!4_J\6X2ZPH"$NL.`H/J!0H8ZP0.BNH!
M"A[K"0[=^-B`3^JQ`4_J\FD>ZPH.W?CPH![K"0Z%Z@$)&.L$"(GJ`@D8ZP,#
MW?C@@!/K"0E/ZK(#3^K^8AGK`@*!Z@,)&.L$"(GJ#@D8ZP4(.IU/ZKX.&.L)
M"$_J\FD8ZPD(@^H."2T9B>H""6D83^JR!1'K"0%/ZOABB1B.Z@4)&NL$`HGJ
M"`G=^/B@TA@2ZPD"3^JX`T_J\6B%Z@,)$NL(`AKK!`B)Z@$)W?@`H1CK#@A/
MZK$!3^KR;ACK"0@8ZPX(@^H!"1KK!`Z)Z@()'NL%#D*=3^JR`A[K"0Y/ZOAI
MW?@0H1[K"0Z!Z@()+1F)Z@@)ZQA/ZK@%$^L)`T_J_F@3ZP@#@NH%"1KK!`B)
MZ@X)&.L!`=WX&*$1ZPD)3^J^`4_J\VZ%Z@$(&>L."1KK!`X>ZP("B.H#"-WX
M(.$2ZP@(3^JS`D_J^6,8ZP,(@>H""A[K!`.*Z@D*71G=^"CA3^JY`Q7K"@5/
MZOAI%>L)!8+J`PD>ZP0.B>H("1[K`0'=^##A3^JX"!'K"0%/ZO5I$>L)`8/J
M"`D>ZP0.B>H%"1[K`@Y.FD_JM04>ZPD.3^KQ:1[K"0Z(Z@4)$AF)Z@$)TAA0
MFT_JL0$2ZPD"3^K^:1+K"0*%Z@$)&QF)Z@X)$^L(!-WX2(%/ZKX.3^KR:A3K
M"01+]MQ#R/8;<Q3K"@1!Z@X)&.L#"*I&">H""4_JL@48ZPH"`>H."MWX4(%)
MZ@H)3NH%"A+K"0)/ZO1I$NL)`@KJ!`H.Z@4)&.L#"$_JM`1*Z@D*&.L!`=WX
M6)%%Z@0(&NL!`4_J\FH(Z@(($>L*`07J!`H9ZP,)2.H*"!GK#@Y/ZK("&.L.
M#MWX8(%$Z@(*3^KQ:1[K"0X*Z@$*!.H""1CK`PA/ZK$!2NH)"ACK!07=^&B1
M0NH!"!KK!05/ZOYJ".H."!7K"@4"Z@$*&>L#"4CJ"@@9ZP0$3^J^#ACK!`3=
M^'"!0>H."D_J]6D4ZPD$"NH%"@'J#@D8ZP,(3^JU!4KJ"0H8ZP("W?AXD4[J
M!0@:ZP("3^KT:@CJ!`@2ZPH"#NH%"AGK`PE(Z@H(&>L!`4_JM`08ZP$!W?B`
M@47J!`I/ZO)I$>L)`0KJ`@H%Z@0)&.L#"$_JL@)*Z@D*&.L.#MWXB)%$Z@((
M&NL.#D_J\6H(Z@$('NL*#AGK`PD$Z@(*3^JQ`4CJ"@H9ZP4%W?B0D4+J`0@:
MZP4%3^K^:A7K"@4(Z@X(`NH!"AGK`PE/ZKX.2.H*"!GK!`IFG$'J#@E/ZO5K
M&.L*"`GJ!0D8ZPL(`>H."N083^JU!4GJ"@JD&&B:3NH%"1KK!`1/ZOAJ%.L*
M!`[J!0L2ZP,*">H("4_JN`))Z@L)&NL!"&J91>H""AGK"`E/ZO1H"NH$"AGK
M"`G)&`7J`@A/ZK0$2NH("!'K#@YLF4+J!`H8ZPX.3^KY:![K"`X"Z@0+R1@*
MZ@D*3^JY"$T92NH+"6Z91.H("AGK!05/ZOYI"NH."A7K"04$Z@@)R1A/ZKX.
MB1A*Z@D*<)I(Z@X+&NL!"4_J]6H9ZPH)"^H%`=(8".H."T_JM05!Z@L+$AER
MF4[J!0I/ZOED&^L"`@KJ"0H2&0[J!0O)&$_JN001ZP@(2NH+"7291>H$"AGK
M"`A/ZO)I&.L)"`7J!`L1ZP,)"NH""D_JL@%*Z@L*&>L.#G::1.H!"1KK#@Y/
MZOAJ">H("1[K"@X$Z@$*TAA/ZK@(2>H*"5(9>)U!Z@@*&>L"`D_J_FD2ZPD"
M"NH."NT8`>H(`TKJ`PHM&7J;3^J^#AKK!05,\M843^KR:LSV8B05ZPH%B.H.
M"1L9B>H""5D8?)M/ZK("3^KU:A'K"0&.Z@()$>L*`1L9B>H%"1/K"`A^FT_J
MM048ZPD(3^KQ:1CK"0B"Z@4)&QF)Z@$)$^L.#H";'NL)"4_JL0%/ZOANA>H!
M"AGK#@X;&9H8BNH("H*;3^JX"!+K"@I/ZOYB&NL"`H'J"`D;&8GJ#@E=&82;
M%>L)"4_JO@Y/ZO)E&>L%!8CJ#@D;&8GJ`@E9&(:;$>L)"4_JL@)/ZO5A&>L!
M`8[J`@D;&8GJ!0D3ZP@(B)L8ZPD)3^JU!4_J\6@9ZP@(@NH%"1L9B>H!"1/K
M#@Z*FQ[K"0E/ZK$!3^KX;AGK#@Z%Z@$)&QF)Z@@)FAB,FQ+K"0E/ZK@(3^K^
M8AGK`@*!Z@@)&QF)Z@X)71F.FQ7K"0E/ZKX.3^KR91GK!06(Z@X)&QF)Z@()
M61B0FQ'K"0E/ZK("3^KU81GK`0&.Z@()&QF)Z@4)$^L(")*;&.L)"4_JM05/
MZO%H&>L("(+J!0D;&8GJ`0D3ZPX.E)L>ZPD)3^JQ`4_J^&X9ZPX.A>H!"1L9
MB>H("9H8EIL2ZPD)3^JX"$_J_F(9ZP("@>H("1L9B>H."5T9F)L5ZPD)3^J^
M#D_J\F49ZP4%B.H."1L9B>H""5D8FIL1ZPD)3^JR`D_J]6$9ZP$!CNH""1L9
MB>H%"1/K"`B<FQCK"0E/ZK4%3^KQ:!GK"`@;&8+J!0D3ZPX.B>H!"9Z;'NL)
M"4_JL0%/ZOAN&>L.#AL9A>H!"9H8B>H(":";$NL)`D_JN`A/ZOYI&QE*1('J
M"`2$Z@X$6QD;&4_J\F0C1$_JO@X3ZPP#LA@#8``D@VD>ZP<'@F`":ACK`P,'
M88D8@V%$8`%B`9NCFL1@&VA$89I"Q&%$8@/1#?4E?;WH\(_^]R[O1&8!`!@!
M```MZ?A#($M[1``H.-`?2IM8T_@`D+GQ``\ST`-XL_$]!1B_`24`*PB_`"6M
MN=GX`$!\L0=&B$9.1BI&.48@1O_W$.@0N6-=/2L/T%;X!$\`+/+1($:]Z/B#
M!485^`$_`"L8OSTK^=$M&N#G`36FZPD&+$2V$,CX`&`@1KWH^(,$1N?G3$;E
MYP"_OED!`$@!``#PM8.P%4\%1A5+;$9_1/Y8,V@!DR%&*$;_]ZK_L+$12P"8
M^U@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48H1O_WE/\`*.C1`9HS
M:)I"`=$#L/"]_O>T[BA9`0`8`0``2`$``"WI\$\,1M_X8)&%L%=+!4;Y1`IX
M6?@#8#TJ"+\!-#-H($8#D_[W%.\"J0=&*$;_]VO_@$8`*%70_O<*[[A"2-)+
M2P*:6?@#D$_J@@@K>+/Q/0`8OP$@`"L(OP`@.+$H1A#X`3\`*QB_/2OYT4`;
M`C?9^`"@.$3^]\CN2O@(```H:=#9^``@*$8"F1#X`3M2^"$0/2L8OP`K"W`)
MT$H<$/@!.Q%&`"L8OSTK`O@!._;1"D8](PMP%/@!.P+X`3\`*_G1`"`#FC-H
MFD)*T06PO>CPCPCQ_S`4^`$[`/@!/P`K^='NYR)+6?@#D-GX`+#;^``PF[-;
M1@#@4$93^`0O`/$!"@`J^-$#,(``&DIZ1!-HL[D!(Q-@_O=X[@&0V+%/ZHH(
M649"1O[WXNT!F\GX`#`*\0$"`"%#^"(0S?@(H(7G`4981O[W'NY/ZHH(`T;)
M^````"CLT4_P_S"SYYI&""#3Y_[W_.T`O[Q8`0`8`0``2`$``%!9`0`V2S=*
M>T0MZ?!/G["=6"MH'9,0L0-X!D8SN1V:*VB:0EG1'["]Z/"/_O<F[@=&`"CS
MT-_XL(#?^+"0W_BPH/A$^43Z1#A&_O>\[@`H.=``\1,$048@1O[W<.T`*/+0
M248@1O[W:NT`*.S0,$;^]S3N@T8@1O[W,.Y81`(P_O<([E-&3_#_,@$A`90`
MEH-&_O="[EE&`JH#(/[WI.X!,%A&!=`&FP/T<$.S]8!/$-#^]ZCM6$;^]V3M
M.$;^]X+N`"C%T3A&_O>L[C!&_O=L[:3G__>6_^WG_O>&[0"_4%<!`!@!``#&
M$@``R!(``,H2```42P%&,+5[1!-,G;`%1@,@:D8<62-H&Y/^]X3N<+D$FP/T
M<$.S]2!/&+^S]8!/!]`;FB-HFD(+T1VP,+T`(/?G*$8"(?[W,NZP^H#P0`GO
MY_[W4.U>5@$`&`$``"WI\$.M]8!=*4R#L"E+#?6`5GQ$`:V`1B=(YU@$-HE&
M0/;_<BE&>$0[:#-@_O=:[2)+`"@OW48>XUBJ71QHTKD.LS)&+R$H1O[W_.W8
ML2!&_O=&[C-&*D9!1O[W$NX-]8!3!#,::#MHFD(>T0WU@%T#L+WH\(,&1B\A
M,D8H1O[WXNT`*./1($;^]RKN2D9!1O[W(NWCY^-8'&@@1O[W(.Y*1D%&_O<8
M[=GG_O?V[`"_]E4!`!@!``"B$0``(`$``!"U"$P(2WQ$XU@8:/[W".X&2@=+
M!TFB6'M$>42]Z!!`_O=^O4)5`0`@`0``'`$``+`0``#^$```#4L.2GM$$+6"
ML)Q8(&C^]^SM__?9_R!H_O?F[0A+`"$(2GM$S>D`,0=)>D1Y1/[WB.T"L!"]
M`+\,50$`(`$``*H3``#W#```T!```"!*(4MZ1/"UK?4`7=58A[`-]0!2'4P4
M,@WU@%8K:'Q$$#838/[W!.T92T'R`0(!(7M$S>D`!`.L($;^]R3M($8Q1D_T
M@%+^]ZSL!!ZXOP`G"MM@'/[WU.P'1BBQ,48B1O[W4NP`(SM5#?4`4SA&%#,:
M:"MHFD(#T0WU`%T'L/"]_O=H[,!4`0`8`0``MA```)@0``#_][2_6TM<2GM$
M+>GP3ZWUA%V;6(.P!D8-]812!J]72`23!#(;:`Q&>$0Y1A-@__<=_2\A!48P
M1O[WR.R8L5!(,49X1/_WCOTP1@WUA%,$,QIH!)L;:)I"0/")@`WUA%T#L+WH
M\(\P1O[WI.Q%27E$@$8@1O[W!NV#1@`HW]!"2]_X"*%[1`63F_@`,/I$W_@`
MD?E$`"M$T"VQ648H1O[WNNL`*$/06$;^]X3L0AX+ZP(#&_@"("\J!M$`(1EP
M`3@3^`$M+RKYT`CQ`0,81+#U@%^TVB&L+TH!(0*6>D1+1@&2($9/](!2S?@`
ML/[W@.PZ1B%&`R#^]^3L*+D[:0/T<$.S]0!/'-`C20`@>43^][KL@T:[\0`/
MD=";^``P`"NZT>VQ448H1O[W=.O@N1M)`"!Y1/[WINR#1KOQ``_LT7WG`2$@
M1O[WF.P`*-S1%$@A1GA$__<&_2!&_O>LZW3GW?@4L`$@K^?31@$@K.?^]ZCK
M`+\H5`$`&`$``!P0```.$```\@\``%P/``!4#P``T@\``)`/``!4#P``+@\`
M`/X.```#>#NQ0APO*PB_$$82^`$[`"OXT7!'`+\0M0`H2-`#>`1&`"M$T/[W
M].L!.",8G$(,TB)<+RH4T5H>`N`9>"\I#]&B0A-&`O'_,O?1G$(3T2-X+RLR
MT!Q(O>@00'A$_O=5NUH>`N`9>"\I!="40A-&`O'_,O?3Z><!.P+@$7@O*031
MG$(:1@/Q_S/WTQ(;DQRS]8!?B+\`(`G8#$@A1@$R3_2`4WA$!$;^]RKK($80
MO0=(O>@00'A$_O<HNP5(O>@00'A$_O<BNVP.``",4P$`A@T``'H-```MZ?!!
MC+!&3`*M1D]\1$9.##1_1-_X%($/S/A$OUD!K@_%#\S7^`#`#\4D:$!(S?@L
MP'A$+(#_]R/\/DAX1/_W'_P]2'A$__<;_#Q(>$3_]Q?\.TAX1/_W$_PZ2'A$
M__</_#E(>$3_]PO\.$AX1/_W!_Q`1O_W!/PU2'A$__<`_#1(>$3_]_S[,T@Q
M1GA$__>O^QBQ`49`1O_W)OPO2#%&>$3_]Z7[(+$!1BU(>$3_]QO\+$@Q1GA$
M__>:^XBQ`48I2'A$__<0_"A)*4AY1'A$__<*_`N:.VB:0A[1#+"]Z/"!)$@Q
M1GA$__>"^RBQ`48A2'A$__?X^^;G($D*(@WQ&0!Y1/[WI.L`*-W1'$@-\2,!
M>$3_]^C[UN?^]Y3J`+\H#0``HE$!`!@!```J#@``P@T``,0-``#$#0``R`T`
M`,@-``#0#0``9`T``,P-``#6#0``4@T``-`-``#0#0``V`T``-H-```&#0``
M]`T``$X-``"Z#0``1@T``+(-```F#0``$DD32GE$$TL0M7M$C%B"L!AH(V@!
MDT,<!=`!FB-HFD(2T0*P$+T,2&E&>$3_]Q[[,+$`>#`H&+\`*!2_`2``(`9+
M>T088.CG_O<ZZBQ0`0`8`0``>E$!`(H,``!"40$`"+7^]_#I_O?BZ0"Q`&@(
MO2%+(DI[1"WI\$&&L)Q8!48?3@2I(VA^1#!&!9/_]^[Z*480L0-X!T93N1I(
M>$3_]V'[!9HC:)I"(]$&L+WH\('^]ZKI`"CTT2A&_O=\ZH!&.$;^]WCJ0$0"
M,/[W4.H.2T_P_S("EWM$S>D`4PM+`2%[1(!&_O>$ZD%&,$;_]SK[U^?^]^;I
M`+^\3P$`&`$``+H,``"D#```B@L``(0+```MZ?!/K?4!3=_XK$:GL-_XK)8-
M]<Q[?$3?^*0V(AT(D/E$!/$0#`?*J_'X!UGX`S"K\>`**#2K\>P(#JX=1@J3
MA^@'`+SH#P#5^`#@JN@/``WU`4.<Z`,`E#/#^`#@BN@#`)3H!P"(Z`<`,4;?
M^%0&>$3_]W/Z(+$#>`1&`"M`\'N!__=E_P5&`"@`\%&!*$;^]PCJ0``!,/[W
MX.DK>`F0@['?^"2&"9SX1`"3($9#1D_P_S(!(0(T_O<2ZA7X`3\`*_+16_C@
M#+BQJ_'<!`+@5/@$"XBQ,4;_]T#Z!48`*/;0`W@`*_/0__?H^P`H[]`H1O[W
M6.F`1B"[`"17^"10];$K>..Q!/$!""A&!^N("D1&__?3^V"Y6O@$6X6Q*WAS
ML0CQ`0@H1D1&__?'^P`H\M`H1O[W-ND`*-_0@$8!X$_P``A`1M_XA$7^]ZSI
M"9]\1`5&.$;^]Z;I!40%\@1%*$;^]WSIW_AH-4_P_S(!(7M$S>D!--_X7#4#
MEWM$S?@`@()&_O>LZ5!&3_3@<?[WO.D!,`71_O>>Z0)H$2I`\-R`,D911@,@
M_O<:Z@1&\+'?^"0E`2$(FP`G6?@"`-_X'"4;:'I$S?@`H`!H_O>ZZ0WU`4,X
M1I0S&F@*FQMHFD)`\%."#?4!32>PO>CPCS-I`_1P0[/U@$_:T;=I_O>:Z(="
MU=$S:</S"`.S]>!_S]$H1O[W).DQ1@=&W_C$!'A$__><^0`H`/"V@`B;'6C^
M][KH`48H1O_W7?P%1@`H`/"J@"A&_O<NZ0,H!D80V=_XE!0$."A$>43^]U3H
M0+D$+@#PPH$N1!;X!3PO*P#PO('_]S[^.+D!1BA&_O?JZ`F0`"A`\(N`W_A@
M%-_X8`1Y1-_X7&1X1-_X7)3_]]OY?D3^]_3HW_A0--_X4!1/\/\R>T0!D]_X
M2#1Y1,WX`*#Y1`.1>T0!(=_X/(3X1`*0.$;^]P;I,T961II&%.#^]_KH`V@1
M*Q?1_O?2Z`$TS?@0@"I&`Y1+1LWX!*`!(0"6`I`X1O[W[NA/].!Q.$;^]_SH
M0QP%1N+0LD901O[W&.CZ2#E&>$3_]Y;Y.$;_]QG^3^<$1@CKA`55^`0+(+,Q
M1@$T__<,^0`H]M`#>``K\]#^]RKH`"CMT`5&F>;?2`$A")L`)UGX```;:,WI
M`*+G2@!H>D3^]^CH*^?_]_+]($;^]Q+H!T8DYPT@X4W^]VCH4R-]1`F0A>8(
MFQUH4N>K\00#;_`1`@B3`B0=1@"43_#_,_[W/.@I1@8B"9C]][;O&_@$/!NY
M:WA#*P#P*H$`)``B`",`E`F8J_'(!O[W*.BLH='I``&LH]/I`".T9\;I`@&K
M\9`!"Y&JH='I``'&Z00CJ:/3Z0`CQND&`:FAT>D``<;I"",`(@`C#)3&Z0HC
MQND,(TOI,@$-ET_T`$+=Z0@0_?=Z[P0><]W6Z0H!YP"@1D_JY'D[&`:3#)LU
M:W=K!Y/=Z08CBT((OX)"`M(!-4?Q``=/ZEARL&]"ZLD"3^I9<U49W>D&$D/K
M!P<U8W=CQND*$@`H2=#`\4`("YN@10B9&$2HOZ!&0D;]]V3OLV]#1+-G0"O`
MT0B;,$:DZP@$F$3^]P[Z/RPHW:3Q0`D(\8`'*?`_`PCQ0`X?1*[Q0`2K\9`,
M(&@0-%3X#!QE1E3X""P,\1`,5/@$/'1%#\7QT3!&_O?N^03Q0`YW1>;13^J9
M%&,<J>N$%`CK@QA!1D@C(D8+F/WW>N^T9X;GW?@@@,GG"9BK\9`%#9_^]U3H
MM&J`(#-KQ//%`B2Z41R3^H/X."FH5&;=P?%``F@8`"']]^+O,$;^][WY*$8X
M(@`A_??:[\;I'(0P1O[WL_FK\40"L6BK\3`%6_C(/*OQ0PL)NE%@,6D8NM_X
MC($;#DOX`0P)NK!I^$218"Q&,6H`NM!@";H180'@&_@!.P"3($9#1D_P_S(!
M(0(T_?>4[UU%\M%62$_P_S)52P$A>$0"E0.0>T3-^`"@.$8!DP`CA?@H,%!+
M>T3]]W[OE^8(FUYH`"X_]#^N,$;]]U;O`RA_]CFN24D$.#!$>43]]W[N`"@(
MOS5&+N9H&,'Q.`(`(?WW?.^?YPB;FWA!*W_TT:X(F]MX0RM_],RN")L;>4@K
M?_3'K@B;6WE%*W_TPJX`E$_P_S,)G&_P.0(@1OWWZNX(G2!&*2(Q3"E&_?=@
M[C!+?$1/\/\R>T0!DRY+`2$"E3A&S?@`H'M$`Y3]]RSO1N;]]Y+N`+^)J\WO
M`````/[<NI@`````=E0R$`````#PX=+#``````$C16<`````7E`!``!/`0`8
M`0``Q`H``*`+```,"P``[`D``-0*```H`0``W`H``-8*``"F"@``G@D``!`)
M``"^"```;@H``*P(```D"P``6@H``!(+```2"```]`@``+`(``"V!@``%`@`
M`(X%```L!P````<``'('``#L!```C`8``)E*FDDMZ?!/>D2'L)A+!*X"EE!8
M`6@#D`61U5@H:/WW4N\$1BAH_?=.[Y3X:#`Q1H#X:3"/2'A$_O?V_ABQ`W@Q
M*P#PYX#_]_?Z*&C]]SKOB4D+(P$B>43]]W+N`"ACT(9*`6EZ1-7X`*!2:-'X
M&(`!*EO=W_@(LD_T@&F!2P`DP/(@"?M$>T0`DRG@`FAF'-OX"`#5^`"@DVA0
M^"9P">H#`[/U@&\(OQ%I#-!01@&1_?<([P&9`B,`(@EH_?<0[M7X`*`!1CA&
M_?>"[0";6V@`*$#PI(`"-)Q"@/*B@#1&4$;]]_#N048`(R)&_?>N[@%&`"C*
MT61*U?@`H'I$4FA1'J%"$M$!*A#=8$X!)%!&?D0`X"AH_??6[D%&_?>"[7-H
M`32C0O7<U?@`H%!&_??*[E=)`R,!(GE$_?<"[@1&:+$H:/WWONXC:5)*&6AZ
M1/WWM.TC:1MHFVA;`F_4*&C]][#N3$D#(P$B>43]]^CM!$9XL4E(`IEX1/[W
M5?X&1BAH`"Y0T/WWGNXC:3)&&6C]]Y3M*&C]]Y;N04Y^1`1&*&C]]Y#N/TD!
M(GE$_??R[3U*>D0!1B!&_?>`[2AH_?>"[@`B`ID#1CA(@_AI('A$_O<J_@1&
M\&"(L4_TX'$@1OWW^.U#'!$H&+\!*S'8`YL%FAMHFD(JT0>PO>CPC[!H__=D
M^P1&\&``*.;1*$AX1/WWTNU#>``K/_07KQ/G&D9NYQI&-$9KY_WW3.XA2R)I
M>T2;:!!H&6C^]]3_JN<H:/WW0.XC:1EH_??6[8?G_?<6[1E)`T892")&>41X
M1(EH"6C]]ZKM`+_D1P$`&`$``"`!```>!```M@4``!A)`0#X2`$`]D@!`(!(
M`0!L2`$`W`0``,H$``"V!```E`(``.!'`0!Z!```B@0``#("```V!```3$<!
M`")'`0`,!```.+4%1O_W6/D#>`1&.[%"'"\K"+\41A+X`3L`*_C1__=M^@`M
M&+\`*`#1.+TK>``K^]`&22!&!")Y1/WWQNT`*//1*$:]Z#A`_O?&OC`"```M
MZ?A#!T8,3HA&#$V11GY$_?=`['U$=ANV$`K0!#T`)`$T5?@$/TI&048X1IA'
MID+VT;WH^(,`O[I#`0"P0P$`<$<`OP)+>T0;:/WWE;P`O^9%`0`(0"WI"("]
MZ`$``@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@(``````N````+BX``"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,
M;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```
M```O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````4$%27U!23T=.04U%````
M`#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"
M54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!005)?0TQ%04X]```Q````
M3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P````!P
M87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````"5S)7-C
M86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M``!!4D=6`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/
M3@`````Q+C`T-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%53
M15).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP
M.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@
M-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ
M92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O
M<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@
M)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@
M)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL
M87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S
M970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@
M)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O
M9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S
M970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY
M("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP
M;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL
M96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@
M)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N
M86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?
M.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N
M+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)
M3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P
M<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K
M("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@
M<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%2
M7T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I
M=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O
M;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@
M9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O
M<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*`'B=_W\!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````!=&```'1@```$````!`````0``
M`,L!```!````&@(```$```!S`P``#````&@2```-````*#H``!D```"<?0$`
M&P````0````:````H'T!`!P````$````]?[_;[0!```%````6`D```8```"8
M`@``"@```.\$```+````$````!4``````````P```+1^`0`"``````(``!0`
M```1````%P```&@0```1````@`\``!(```#H````$P````@````>````"```
M`/O__V\!```(_O__;R`/``#___]O`P```/#__V](#@``^O__;Q``````````
M````````````````````````````````````````````````I'T!````````
M````=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02
M``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(`
M`'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``
M=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T
M$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``'02
M``!T$@``=!(``'02``!T$@``=!(``'02``!T$@``=!(``!4Z````````````
M``````````````````````````````````````#5.0```````)D5````````
M````````````````!(`!`/____^</0``9#H```````"$.P``B#L``)`]``#,
M.@``F#T```````!\/0``A#T```````"D/0``1T-#.B`H56)U;G1U(#@N,BXP
M+3$P=6)U;G1U,2D@."XR+C``03(```!A96%B:0`!*`````4W+4$`!@H'00@!
M"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN
M<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN
M9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE
M>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``
M````````````````````````````````````````````````````"P````$`
M```"````5`$``%0!```9```````````````!`````````!,````'`````@``
M`'`!``!P`0``(```````````````!``````````A````!P````(```"0`0``
MD`$``"0```````````````0`````````-````/;__V\"````M`$``+0!``#D
M````!0`````````$````!````#X````+`````@```)@"``"8`@``P`8```8`
M```#````!````!````!&`````P````(```!8"0``6`D``.\$````````````
M``$`````````3@```/___V\"````2`X``$@.``#8````!0`````````"````
M`@```%L```#^__]O`@```"`/```@#P``8`````8````#````!`````````!J
M````"0````(```"`#P``@`\``.@````%``````````0````(````<P````D`
M``!"````:!```&@0`````@``!0```!4````$````"````'P````!````!@``
M`&@2``!H$@``#```````````````!`````````!W`````0````8```!T$@``
M=!(``"`#``````````````0````$````@@````$````&````F!4``)@5``"0
M)``````````````(`````````(@````!````!@```"@Z```H.@``"```````
M````````!`````````".`````0````(````P.@``,#H``*@_````````````
M``0`````````E@````$``'""````V'D``-AY```(````#0`````````$````
M`````*$````!`````@```.!Y``#@>0``!```````````````!`````````"K
M````#@````,```"<?0$`G'T```0```````````````0````$````MP````\`
M```#````H'T!`*!]```$```````````````$````!````,,````&`````P``
M`*1]`0"D?0``$`$```8`````````!`````@```#,`````0````,```"T?@$`
MM'X``$P!``````````````0````$````T0````$````#`````(`!``"```!`
M```````````````$`````````-<````(`````P```$"``0!`@```&!``````
M````````!`````````#<`````0```#``````````0(```"0`````````````
M``$````!````Y0````,``'```````````&2````S```````````````!````
L``````$````#``````````````"7@```]0```````````````0``````````
